@@ -1,4 +1,4 @@
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import,unused-argument,super-init-not-called
 """
 Main interface for wafv2 service client
 
@@ -14,7 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type
 
-from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.client import ClientMeta
 
 from mypy_boto3_wafv2.type_defs import (
     CheckCapacityResponseTypeDef,
@@ -64,47 +64,56 @@ else:
 __all__ = ("WAFV2Client",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    WAFAssociatedItemException: Type[Boto3ClientError]
-    WAFDuplicateItemException: Type[Boto3ClientError]
-    WAFInternalErrorException: Type[Boto3ClientError]
-    WAFInvalidOperationException: Type[Boto3ClientError]
-    WAFInvalidParameterException: Type[Boto3ClientError]
-    WAFInvalidPermissionPolicyException: Type[Boto3ClientError]
-    WAFInvalidResourceException: Type[Boto3ClientError]
-    WAFLimitsExceededException: Type[Boto3ClientError]
-    WAFNonexistentItemException: Type[Boto3ClientError]
-    WAFOptimisticLockException: Type[Boto3ClientError]
-    WAFServiceLinkedRoleErrorException: Type[Boto3ClientError]
-    WAFSubscriptionNotFoundException: Type[Boto3ClientError]
-    WAFTagOperationException: Type[Boto3ClientError]
-    WAFTagOperationInternalErrorException: Type[Boto3ClientError]
-    WAFUnavailableEntityException: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    WAFAssociatedItemException: Type[BotocoreClientError]
+    WAFDuplicateItemException: Type[BotocoreClientError]
+    WAFInternalErrorException: Type[BotocoreClientError]
+    WAFInvalidOperationException: Type[BotocoreClientError]
+    WAFInvalidParameterException: Type[BotocoreClientError]
+    WAFInvalidPermissionPolicyException: Type[BotocoreClientError]
+    WAFInvalidResourceException: Type[BotocoreClientError]
+    WAFLimitsExceededException: Type[BotocoreClientError]
+    WAFNonexistentItemException: Type[BotocoreClientError]
+    WAFOptimisticLockException: Type[BotocoreClientError]
+    WAFServiceLinkedRoleErrorException: Type[BotocoreClientError]
+    WAFSubscriptionNotFoundException: Type[BotocoreClientError]
+    WAFTagOperationException: Type[BotocoreClientError]
+    WAFTagOperationInternalErrorException: Type[BotocoreClientError]
+    WAFUnavailableEntityException: Type[BotocoreClientError]
 
 
 class WAFV2Client:
     """
-    [WAFV2.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client)
+    [WAFV2.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def associate_web_acl(self, WebACLArn: str, ResourceArn: str) -> Dict[str, Any]:
         """
-        [Client.associate_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.associate_web_acl)
+        [Client.associate_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.associate_web_acl)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.can_paginate)
         """
 
     def check_capacity(
         self, Scope: Literal["CLOUDFRONT", "REGIONAL"], Rules: List["RuleTypeDef"]
     ) -> CheckCapacityResponseTypeDef:
         """
-        [Client.check_capacity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.check_capacity)
+        [Client.check_capacity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.check_capacity)
         """
 
     def create_ip_set(
@@ -117,7 +126,7 @@ class WAFV2Client:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateIPSetResponseTypeDef:
         """
-        [Client.create_ip_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.create_ip_set)
+        [Client.create_ip_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.create_ip_set)
         """
 
     def create_regex_pattern_set(
@@ -129,7 +138,7 @@ class WAFV2Client:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateRegexPatternSetResponseTypeDef:
         """
-        [Client.create_regex_pattern_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.create_regex_pattern_set)
+        [Client.create_regex_pattern_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.create_regex_pattern_set)
         """
 
     def create_rule_group(
@@ -143,7 +152,7 @@ class WAFV2Client:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateRuleGroupResponseTypeDef:
         """
-        [Client.create_rule_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.create_rule_group)
+        [Client.create_rule_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.create_rule_group)
         """
 
     def create_web_acl(
@@ -157,64 +166,64 @@ class WAFV2Client:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateWebACLResponseTypeDef:
         """
-        [Client.create_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.create_web_acl)
+        [Client.create_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.create_web_acl)
         """
 
     def delete_firewall_manager_rule_groups(
         self, WebACLArn: str, WebACLLockToken: str
     ) -> DeleteFirewallManagerRuleGroupsResponseTypeDef:
         """
-        [Client.delete_firewall_manager_rule_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.delete_firewall_manager_rule_groups)
+        [Client.delete_firewall_manager_rule_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.delete_firewall_manager_rule_groups)
         """
 
     def delete_ip_set(
         self, Name: str, Scope: Literal["CLOUDFRONT", "REGIONAL"], Id: str, LockToken: str
     ) -> Dict[str, Any]:
         """
-        [Client.delete_ip_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.delete_ip_set)
+        [Client.delete_ip_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.delete_ip_set)
         """
 
     def delete_logging_configuration(self, ResourceArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_logging_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.delete_logging_configuration)
+        [Client.delete_logging_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.delete_logging_configuration)
         """
 
     def delete_permission_policy(self, ResourceArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_permission_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.delete_permission_policy)
+        [Client.delete_permission_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.delete_permission_policy)
         """
 
     def delete_regex_pattern_set(
         self, Name: str, Scope: Literal["CLOUDFRONT", "REGIONAL"], Id: str, LockToken: str
     ) -> Dict[str, Any]:
         """
-        [Client.delete_regex_pattern_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.delete_regex_pattern_set)
+        [Client.delete_regex_pattern_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.delete_regex_pattern_set)
         """
 
     def delete_rule_group(
         self, Name: str, Scope: Literal["CLOUDFRONT", "REGIONAL"], Id: str, LockToken: str
     ) -> Dict[str, Any]:
         """
-        [Client.delete_rule_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.delete_rule_group)
+        [Client.delete_rule_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.delete_rule_group)
         """
 
     def delete_web_acl(
         self, Name: str, Scope: Literal["CLOUDFRONT", "REGIONAL"], Id: str, LockToken: str
     ) -> Dict[str, Any]:
         """
-        [Client.delete_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.delete_web_acl)
+        [Client.delete_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.delete_web_acl)
         """
 
     def describe_managed_rule_group(
         self, VendorName: str, Name: str, Scope: Literal["CLOUDFRONT", "REGIONAL"]
     ) -> DescribeManagedRuleGroupResponseTypeDef:
         """
-        [Client.describe_managed_rule_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.describe_managed_rule_group)
+        [Client.describe_managed_rule_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.describe_managed_rule_group)
         """
 
     def disassociate_web_acl(self, ResourceArn: str) -> Dict[str, Any]:
         """
-        [Client.disassociate_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.disassociate_web_acl)
+        [Client.disassociate_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.disassociate_web_acl)
         """
 
     def generate_presigned_url(
@@ -225,24 +234,24 @@ class WAFV2Client:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.generate_presigned_url)
         """
 
     def get_ip_set(
         self, Name: str, Scope: Literal["CLOUDFRONT", "REGIONAL"], Id: str
     ) -> GetIPSetResponseTypeDef:
         """
-        [Client.get_ip_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.get_ip_set)
+        [Client.get_ip_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.get_ip_set)
         """
 
     def get_logging_configuration(self, ResourceArn: str) -> GetLoggingConfigurationResponseTypeDef:
         """
-        [Client.get_logging_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.get_logging_configuration)
+        [Client.get_logging_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.get_logging_configuration)
         """
 
     def get_permission_policy(self, ResourceArn: str) -> GetPermissionPolicyResponseTypeDef:
         """
-        [Client.get_permission_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.get_permission_policy)
+        [Client.get_permission_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.get_permission_policy)
         """
 
     def get_rate_based_statement_managed_keys(
@@ -253,21 +262,21 @@ class WAFV2Client:
         RuleName: str,
     ) -> GetRateBasedStatementManagedKeysResponseTypeDef:
         """
-        [Client.get_rate_based_statement_managed_keys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.get_rate_based_statement_managed_keys)
+        [Client.get_rate_based_statement_managed_keys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.get_rate_based_statement_managed_keys)
         """
 
     def get_regex_pattern_set(
         self, Name: str, Scope: Literal["CLOUDFRONT", "REGIONAL"], Id: str
     ) -> GetRegexPatternSetResponseTypeDef:
         """
-        [Client.get_regex_pattern_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.get_regex_pattern_set)
+        [Client.get_regex_pattern_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.get_regex_pattern_set)
         """
 
     def get_rule_group(
         self, Name: str, Scope: Literal["CLOUDFRONT", "REGIONAL"], Id: str
     ) -> GetRuleGroupResponseTypeDef:
         """
-        [Client.get_rule_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.get_rule_group)
+        [Client.get_rule_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.get_rule_group)
         """
 
     def get_sampled_requests(
@@ -279,33 +288,33 @@ class WAFV2Client:
         MaxItems: int,
     ) -> GetSampledRequestsResponseTypeDef:
         """
-        [Client.get_sampled_requests documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.get_sampled_requests)
+        [Client.get_sampled_requests documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.get_sampled_requests)
         """
 
     def get_web_acl(
         self, Name: str, Scope: Literal["CLOUDFRONT", "REGIONAL"], Id: str
     ) -> GetWebACLResponseTypeDef:
         """
-        [Client.get_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.get_web_acl)
+        [Client.get_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.get_web_acl)
         """
 
     def get_web_acl_for_resource(self, ResourceArn: str) -> GetWebACLForResourceResponseTypeDef:
         """
-        [Client.get_web_acl_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.get_web_acl_for_resource)
+        [Client.get_web_acl_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.get_web_acl_for_resource)
         """
 
     def list_available_managed_rule_groups(
         self, Scope: Literal["CLOUDFRONT", "REGIONAL"], NextMarker: str = None, Limit: int = None
     ) -> ListAvailableManagedRuleGroupsResponseTypeDef:
         """
-        [Client.list_available_managed_rule_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.list_available_managed_rule_groups)
+        [Client.list_available_managed_rule_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.list_available_managed_rule_groups)
         """
 
     def list_ip_sets(
         self, Scope: Literal["CLOUDFRONT", "REGIONAL"], NextMarker: str = None, Limit: int = None
     ) -> ListIPSetsResponseTypeDef:
         """
-        [Client.list_ip_sets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.list_ip_sets)
+        [Client.list_ip_sets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.list_ip_sets)
         """
 
     def list_logging_configurations(
@@ -315,66 +324,66 @@ class WAFV2Client:
         Limit: int = None,
     ) -> ListLoggingConfigurationsResponseTypeDef:
         """
-        [Client.list_logging_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.list_logging_configurations)
+        [Client.list_logging_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.list_logging_configurations)
         """
 
     def list_regex_pattern_sets(
         self, Scope: Literal["CLOUDFRONT", "REGIONAL"], NextMarker: str = None, Limit: int = None
     ) -> ListRegexPatternSetsResponseTypeDef:
         """
-        [Client.list_regex_pattern_sets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.list_regex_pattern_sets)
+        [Client.list_regex_pattern_sets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.list_regex_pattern_sets)
         """
 
     def list_resources_for_web_acl(
         self,
         WebACLArn: str,
-        ResourceType: Literal["APPLICATION_LOAD_BALANCER", "API_GATEWAY"] = None,
+        ResourceType: Literal["APPLICATION_LOAD_BALANCER", "API_GATEWAY", "APPSYNC"] = None,
     ) -> ListResourcesForWebACLResponseTypeDef:
         """
-        [Client.list_resources_for_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.list_resources_for_web_acl)
+        [Client.list_resources_for_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.list_resources_for_web_acl)
         """
 
     def list_rule_groups(
         self, Scope: Literal["CLOUDFRONT", "REGIONAL"], NextMarker: str = None, Limit: int = None
     ) -> ListRuleGroupsResponseTypeDef:
         """
-        [Client.list_rule_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.list_rule_groups)
+        [Client.list_rule_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.list_rule_groups)
         """
 
     def list_tags_for_resource(
         self, ResourceARN: str, NextMarker: str = None, Limit: int = None
     ) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.list_tags_for_resource)
         """
 
     def list_web_acls(
         self, Scope: Literal["CLOUDFRONT", "REGIONAL"], NextMarker: str = None, Limit: int = None
     ) -> ListWebACLsResponseTypeDef:
         """
-        [Client.list_web_acls documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.list_web_acls)
+        [Client.list_web_acls documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.list_web_acls)
         """
 
     def put_logging_configuration(
         self, LoggingConfiguration: "LoggingConfigurationTypeDef"
     ) -> PutLoggingConfigurationResponseTypeDef:
         """
-        [Client.put_logging_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.put_logging_configuration)
+        [Client.put_logging_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.put_logging_configuration)
         """
 
     def put_permission_policy(self, ResourceArn: str, Policy: str) -> Dict[str, Any]:
         """
-        [Client.put_permission_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.put_permission_policy)
+        [Client.put_permission_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.put_permission_policy)
         """
 
     def tag_resource(self, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.untag_resource)
         """
 
     def update_ip_set(
@@ -387,7 +396,7 @@ class WAFV2Client:
         Description: str = None,
     ) -> UpdateIPSetResponseTypeDef:
         """
-        [Client.update_ip_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.update_ip_set)
+        [Client.update_ip_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.update_ip_set)
         """
 
     def update_regex_pattern_set(
@@ -400,7 +409,7 @@ class WAFV2Client:
         Description: str = None,
     ) -> UpdateRegexPatternSetResponseTypeDef:
         """
-        [Client.update_regex_pattern_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.update_regex_pattern_set)
+        [Client.update_regex_pattern_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.update_regex_pattern_set)
         """
 
     def update_rule_group(
@@ -414,7 +423,7 @@ class WAFV2Client:
         Rules: List["RuleTypeDef"] = None,
     ) -> UpdateRuleGroupResponseTypeDef:
         """
-        [Client.update_rule_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.update_rule_group)
+        [Client.update_rule_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.update_rule_group)
         """
 
     def update_web_acl(
@@ -429,5 +438,5 @@ class WAFV2Client:
         Rules: List["RuleTypeDef"] = None,
     ) -> UpdateWebACLResponseTypeDef:
         """
-        [Client.update_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.40/reference/services/wafv2.html#WAFV2.Client.update_web_acl)
+        [Client.update_web_acl documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.1/reference/services/wafv2.html#WAFV2.Client.update_web_acl)
         """
